<!-- Generated with Stardoc: http://skydoc.bazel.build -->

wrapper macro for rollup rule

<a id="rollup"></a>

## rollup

<pre>
rollup(<a href="#rollup-name">name</a>, <a href="#rollup-node_modules">node_modules</a>, <a href="#rollup-entry_point">entry_point</a>, <a href="#rollup-entry_points">entry_points</a>, <a href="#rollup-srcs">srcs</a>, <a href="#rollup-deps">deps</a>, <a href="#rollup-args">args</a>, <a href="#rollup-config_file">config_file</a>, <a href="#rollup-format">format</a>,
       <a href="#rollup-output_dir">output_dir</a>, <a href="#rollup-silent">silent</a>, <a href="#rollup-silent_on_success">silent_on_success</a>, <a href="#rollup-sourcemap">sourcemap</a>, <a href="#rollup-data">data</a>, <a href="#rollup-kwargs">kwargs</a>)
</pre>

Runs the rollup bundler under Bazel

For further information about rollup, see https://rollupjs.org/


**PARAMETERS**


| Name  | Description | Default Value |
| :------------- | :------------- | :------------- |
| <a id="rollup-name"></a>name |  A unique name for this target.   |  none |
| <a id="rollup-node_modules"></a>node_modules |  Label pointing to the linked node_modules target where the <code>rollup</code> is linked, e.g. <code>//:node_modules</code>.<br><br><code>rollup</code> must be linked into the node_modules supplied.   |  none |
| <a id="rollup-entry_point"></a>entry_point |  The bundle's entry point (e.g. your main.js or app.js or index.js).<br><br>This is just a shortcut for the <code>entry_points</code> attribute with a single output chunk named the same as the rule.<br><br>For example, these are equivalent:<br><br><pre><code>python rollup(     name = "bundle",     node_modules = "//:node_modules",     entry_point = "index.js", ) </code></pre><br><br><pre><code>python rollup(     name = "bundle",     node_modules = "//:node_modules",     entry_points = {         "index.js": "bundle"     } ) </code></pre><br><br>If <code>rollup</code> is used on a <code>ts_library</code>, the <code>rollup</code> rule handles selecting the correct outputs from <code>ts_library</code>.<br><br>In this case, <code>entry_point</code> can be specified as the <code>.ts</code> file and <code>rollup</code> will handle the mapping to the <code>.mjs</code> output file.<br><br>For example:<br><br><pre><code>python ts_library(     name = "foo",     srcs = [         "foo.ts",         "index.ts",     ], ) rollup(     name = "bundle",     node_modules = "//:node_modules",     deps = [ "foo" ],     entry_point = "index.ts", ) </code></pre>   |  <code>None</code> |
| <a id="rollup-entry_points"></a>entry_points |  The bundle's entry points (e.g. your main.js or app.js or index.js).<br><br>Passed to the [<code>--input</code> option](https://github.com/rollup/rollup/blob/master/docs/999-big-list-of-options.md#input) in Rollup.<br><br>Keys in this dictionary are labels pointing to .js entry point files.<br><br>Values are the name to be given to the corresponding output chunk.<br><br>Either this attribute or <code>entry_point</code> must be specified, but not both.   |  <code>{}</code> |
| <a id="rollup-srcs"></a>srcs |  Non-entry point JavaScript source files from the workspace.<br><br>You must not repeat file(s) passed to entry_point/entry_points.   |  <code>[]</code> |
| <a id="rollup-deps"></a>deps |  Other libraries that are required by the code, or by the rollup.config.js.   |  <code>[]</code> |
| <a id="rollup-args"></a>args |  Command line arguments to pass to Rollup. Can be used to override config file settings.<br><br>These argument passed on the command line before arguments that are added by the rule.<br><br>Run <code>bazel</code> with <code>--subcommands</code> to see what Rollup CLI command line was invoked.<br><br>See the &lt;a href="https://rollupjs.org/guide/en/#command-line-flags"&gt;Rollup CLI docs&lt;/a&gt; for a complete list of supported arguments.   |  <code>[]</code> |
| <a id="rollup-config_file"></a>config_file |  A <code>rollup.config.js</code> file<br><br>Passed to the <code>--config</code> option, see [the config doc](https://rollupjs.org/guide/en/#configuration-files)<br><br>If not set, a default basic Rollup config is used.   |  <code>"@aspect_rules_rollup//rollup:rollup.config"</code> |
| <a id="rollup-format"></a>format |  Specifies the format of the generated bundle. One of the following:<br><br>- <code>amd</code>: Asynchronous Module Definition, used with module loaders like RequireJS - <code>cjs</code>: CommonJS, suitable for Node and other bundlers - <code>esm</code>: Keep the bundle as an ES module file, suitable for other bundlers and inclusion as a <code>&lt;script type=module&gt;</code> tag in modern browsers - <code>iife</code>: A self-executing function, suitable for inclusion as a <code>&lt;script&gt;</code> tag. (If you want to create a bundle for your application, you probably want to use this.) - <code>umd</code>: Universal Module Definition, works as amd, cjs and iife all in one - <code>system</code>: Native format of the SystemJS loader   |  <code>"esm"</code> |
| <a id="rollup-output_dir"></a>output_dir |  Whether to produce a directory output.<br><br>We will use the [<code>--output.dir</code> option](https://github.com/rollup/rollup/blob/master/docs/999-big-list-of-options.md#outputdir) in rollup rather than <code>--output.file</code>.<br><br>If the program produces multiple chunks, you must specify this attribute.<br><br>Otherwise, the outputs are assumed to be a single file.   |  <code>False</code> |
| <a id="rollup-silent"></a>silent |  Whether to execute the rollup binary with the --silent flag, defaults to False.<br><br>Using --silent can cause rollup to [ignore errors/warnings](https://github.com/rollup/rollup/blob/master/docs/999-big-list-of-options.md#onwarn) which are only surfaced via logging.  Since bazel expects printing nothing on success, setting silent to True is a more Bazel-idiomatic experience, however could cause rollup to drop important warnings.   |  <code>False</code> |
| <a id="rollup-silent_on_success"></a>silent_on_success |  Even stronger than --silent, defaults to False.<br><br>Since the build still emits some texted, even when passed --silent, this uses the same flag as npm_package_bin to supress all output on success.   |  <code>False</code> |
| <a id="rollup-sourcemap"></a>sourcemap |  Whether to produce sourcemaps.<br><br>Passed to the [<code>--sourcemap</code> option](https://github.com/rollup/rollup/blob/master/docs/999-big-list-of-options.md#outputsourcemap") in Rollup   |  <code>"inline"</code> |
| <a id="rollup-data"></a>data |  Runtime dependencies to include in binaries/tests that depend on this target.<br><br>The transitive npm dependencies, transitive sources, default outputs and runfiles of targets in the <code>data</code> attribute are added to the runfiles of this target. They should appear in the '*.runfiles' area of any executable which has a runtime dependency on this target.<br><br>If this list contains linked npm packages, npm package store targets or other targets that provide <code>JsInfo</code>, <code>NpmPackageStoreInfo</code> providers are gathered from <code>JsInfo</code>. This is done directly from the <code>npm_package_store_deps</code> field of these. For linked npm package targets, the underlying <code>npm_package_store</code> target(s) that back the links is used. Gathered <code>NpmPackageStoreInfo</code> providers are propagated to the direct dependencies of downstream linked <code>npm_package</code> targets.<br><br>NB: Linked npm package targets that are "dev" dependencies do not forward their underlying <code>npm_package_store</code> target(s) through <code>npm_package_store_deps</code> and will therefore not be propagated to the direct dependencies of downstream linked <code>npm_package</code> targets. npm packages that come in from <code>npm_translate_lock</code> are considered "dev" dependencies if they are have <code>dev: true</code> set in the pnpm lock file. This should be all packages that are only listed as "devDependencies" in all <code>package.json</code> files within the pnpm workspace. This behavior is intentional to mimic how <code>devDependencies</code> work in published npm packages.   |  <code>[]</code> |
| <a id="rollup-kwargs"></a>kwargs |  Other common arguments such as <code>tags</code> and <code>visibility</code>   |  none |


